@@ -1,5 +1,5 @@
 package Util::Medley::DateTime;
-$Util::Medley::DateTime::VERSION = '0.006';
+$Util::Medley::DateTime::VERSION = '0.007';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -13,7 +13,7 @@ Util::Medley::DateTime - Class with various datetime methods.
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =cut
 
@@ -47,6 +47,24 @@ none
 
 Returns the local date/time in the format: YYYY-MM-DD HH:MM:SS.  
 
+=over
+
+=item usage:
+
+ $dt->localdatetime([ $time ]);
+ 
+=item args:
+
+=over
+
+=item time [Int]
+
+Epoch time used to generate date/time string.  Default is now.
+
+=back
+
+=back
+   
 =cut
 
 method localdatetime ($time = time) {
